@@ -2,11 +2,11 @@ use 5.008;
 use strict;
 use warnings;
 package BenchmarkAnything::Schema;
-BEGIN {
-  $BenchmarkAnything::Schema::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.002-1-g978c3c0
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Tooling to handle the "BenchmarkAnything" schema
-$BenchmarkAnything::Schema::VERSION = '0.002';
+$BenchmarkAnything::Schema::VERSION = '0.003';
 
 
 sub valid_json_schema {
@@ -74,7 +74,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
